@@ -1,5 +1,4 @@
 from dataclasses import dataclass
-from typing import List, Optional
 
 from neoteroi.mkdocs.markdown.images import Image
 
@@ -7,11 +6,11 @@ from neoteroi.mkdocs.markdown.images import Image
 @dataclass
 class CardItem:
     title: str
-    url: Optional[str] = None
-    content: Optional[str] = None
-    icon: Optional[str] = None
-    key: Optional[str] = None
-    image: Optional[Image] = None
+    url: str | None = None
+    content: str | None = None
+    icon: str | None = None
+    key: str | None = None
+    image: Image | None = None
 
     def __post_init__(self):
         if self.image and not self.image.alt:
@@ -20,4 +19,4 @@ class CardItem:
 
 @dataclass
 class Cards:
-    items: List[CardItem]
+    items: list[CardItem]
