@@ -2,7 +2,6 @@ from abc import ABC, abstractmethod
 from dataclasses import dataclass
 from datetime import datetime
 from pathlib import Path
-from typing import List, Optional
 
 
 @dataclass
@@ -10,13 +9,13 @@ class Contributor:
     name: str
     email: str
     count: int = -1
-    image: Optional[str] = None
-    key: Optional[str] = None
+    image: str | None = None
+    key: str | None = None
 
 
 class ContributionsReader(ABC):
     @abstractmethod
-    def get_contributors(self, file_path: Path) -> List[Contributor]:
+    def get_contributors(self, file_path: Path) -> list[Contributor]:
         """Obtains the list of contributors for a file with the given path."""
 
     @abstractmethod
